==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgedittimer.cpp <==
/***************************************************************************
                          dlgedittimer.cpp  -  Edit Timer dialog
                             -------------------
    begin                : So mj 10 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "../dialogs/dlgedittimer.h"

#include "../ctimer.h"

#include <qcheckbox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qwhatsthis.h>

#include <knuminput.h>
#include <klineedit.h>
#include <klocale.h>

dlgEditTimer::dlgEditTimer (cTimer *t, QWidget *parent, const char *name ) :
    KDialogBase (parent, name, true, i18n ("Edit timer"), Ok|Cancel, Ok)
{
  timer = t;

  createDialog ();
}

dlgEditTimer::~dlgEditTimer ()
{

}

void dlgEditTimer::createDialog ()
{
  //initial dialog size
  setInitialSize (QSize (300, 150));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QGridLayout *layout = new QGridLayout (page, 4, 2);

  setMainWidget (page);

  //command
  QLabel *lbl1 = new QLabel (i18n ("&Command"), page);
  cmd = new KLineEdit (page);
  lbl1->setBuddy (cmd);
  QWhatsThis::add (cmd, i18n ("Command that will be executed on each timeout.\n"
      "Command can include aliases, script calls and similar stuff."));

  //interval
  QLabel *lbl2 = new QLabel (i18n ("&Interval"), page);
  interval = new KIntNumInput (page);
  interval->setMinValue (1);
  interval->setMaxValue (3600);  //max = 1 hod.
  interval->setSuffix (i18n (" secs"));
  lbl2->setBuddy (interval);

  //single-shot
  chksingleshot = new QCheckBox (i18n ("&Single-shot"), page);
  QWhatsThis::add (cmd, i18n ("When enabled, the timer will only be executed once."));

  //place'em there!
  layout->setSpacing (5);
  layout->addWidget (lbl1, 0, 0);
  layout->addWidget (cmd, 0, 1);
  layout->addWidget (lbl2, 1, 0);
  layout->addWidget (interval, 1, 1);
  layout->addMultiCellWidget (chksingleshot, 2, 2, 0, 1);
  layout->setRowStretch (3, 10);
}

bool dlgEditTimer::showMe ()
//fills and shows the dialog, then applies changes if needed
{
  //fill in the dialog
  cmd->setText (timer->command ());
  chksingleshot->setChecked (timer->singleShot ());
  interval->setValue (timer->interval ());
  
  //show it!
  int n = exec ();

  //update structure if needed
  if (n == Accepted)
  {
    timer->setCommand (cmd->text ());
    timer->setSingleShot (chksingleshot->isChecked ());
    timer->setInterval (interval->value ());
    return true;
  }
  else
    return false;
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgedittimer.cpp <==
/***************************************************************************
                          dlgedittimer.cpp  -  Edit Timer dialog
                             -------------------
    begin                : So mj 10 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dlgedittimer.h"

#include "ctimer.h"

#include <qcheckbox.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qwhatsthis.h>

#include <knuminput.h>
#include <klineedit.h>
#include <klocale.h>

dlgEditTimer::dlgEditTimer (cTimer *t, QWidget *parent, const char *name ) :
    KDialogBase (parent, name, true, i18n ("Edit timer"), Ok|Cancel, Ok)
{
  timer = t;

  createDialog ();
}

dlgEditTimer::~dlgEditTimer ()
{

}

void dlgEditTimer::createDialog ()
{
  //initial dialog size
  setInitialSize (QSize (300, 150));

  //create main dialog's widget
  QWidget *page = new QWidget (this);
  QGridLayout *layout = new QGridLayout (page, 4, 2);

  setMainWidget (page);

  //command
  QLabel *lbl1 = new QLabel (i18n ("&Command"), page);
  cmd = new KLineEdit (page);
  lbl1->setBuddy (cmd);
  QWhatsThis::add (cmd, i18n ("Command that will be executed on each timeout.\n"
      "Command can include aliases, script calls and similar stuff."));

  //interval
  QLabel *lbl2 = new QLabel (i18n ("&Interval"), page);
  interval = new KIntNumInput (page);
  interval->setMinValue (1);
  interval->setMaxValue (3600);  //max = 1 hod.
  interval->setSuffix (i18n (" secs"));
  lbl2->setBuddy (interval);

  //single-shot
  chksingleshot = new QCheckBox (i18n ("&Single-shot"), page);
  QWhatsThis::add (cmd, i18n ("When enabled, the timer will only be executed once."));

  //place'em there!
  layout->setSpacing (5);
  layout->addWidget (lbl1, 0, 0);
  layout->addWidget (cmd, 0, 1);
  layout->addWidget (lbl2, 1, 0);
  layout->addWidget (interval, 1, 1);
  layout->addMultiCellWidget (chksingleshot, 2, 2, 0, 1);
  layout->setRowStretch (3, 10);
}

bool dlgEditTimer::showMe ()
//fills and shows the dialog, then applies changes if needed
{
  //fill in the dialog
  cmd->setText (timer->command ());
  chksingleshot->setChecked (timer->singleShot ());
  interval->setValue (timer->interval ());
  
  //show it!
  int n = exec ();

  //update structure if needed
  if (n == Accepted)
  {
    timer->setCommand (cmd->text ());
    timer->setSingleShot (chksingleshot->isChecked ());
    timer->setInterval (interval->value ());
    return true;
  }
  else
    return false;
}
